StateWithHashableSignatureVariables

Struct StateWithHashableSignatureVariables 

pub struct StateWithHashableSignatureVariables {
    pub signature_variables: HashableSignatureVariables,
    pub resource_variables: ResourceVariables,
}
State that can be hashed by signature variables.

However, using continuous variables in signature variables is not recommended because it may cause a numerical issue.

Fields

signature_variables: HashableSignatureVariables

Signature variables.

resource_variables: ResourceVariables

Resource variables.