pub struct StateWithHashableSignatureVariables {
pub signature_variables: HashableSignatureVariables,
pub resource_variables: ResourceVariables,
}Expand description
State that can be hashed by signature variables.
However, using continuous variables in signature variables is not recommended because it may cause a numerical issue.
Fields
signature_variables: HashableSignatureVariablesSignature variables.
resource_variables: ResourceVariablesResource variables.